"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.applyDisclosureFrame = void 0;
const utils_1 = require("@sd-jwt/utils");
const decoys_1 = require("./decoys");
const disclosures_1 = require("./disclosures");
const error_1 = require("./error");
const applyDisclosureFrame = (saltGenerator, hasherAndAlgorithm, payload, frame, keys = [], cleanup = [], disclosures = []) => __awaiter(void 0, void 0, void 0, function* () {
    var _a, _b;
    for (const [key, frameValue] of Object.entries(frame)) {
        const newKeys = [...keys, key];
        if (key === '__decoyCount' && typeof frameValue === 'number') {
            const sd = Array.from((_a = payload._sd) !== null && _a !== void 0 ? _a : []);
            const decoys = yield (0, decoys_1.createDecoys)(frameValue, saltGenerator, hasherAndAlgorithm);
            decoys.forEach((digest) => sd.push(digest));
            // @ts-ignore
            payload._sd = sd.sort();
        }
        else if (typeof frameValue === 'boolean') {
            if (frameValue === true) {
                if (!(key in payload)) {
                    throw new error_1.SdJwtError(`key, ${key}, is not inside the payload (${JSON.stringify(payload)}), but it was supplied inside the frame.`);
                }
                const salt = yield saltGenerator();
                const disclosure = yield new disclosures_1.Disclosure(salt, payload[key], key).withCalculateDigest(hasherAndAlgorithm);
                disclosures.push(disclosure);
                const sd = Array.from((_b = payload._sd) !== null && _b !== void 0 ? _b : []);
                sd.push(disclosure.digest);
                //@ts-ignore
                payload._sd = sd.sort();
                cleanup.push(newKeys);
            }
        }
        else if (typeof frameValue === 'object' &&
            !Array.isArray(frameValue)) {
            yield (0, exports.applyDisclosureFrame)(saltGenerator, hasherAndAlgorithm, payload[key], frameValue, newKeys, cleanup, disclosures);
        }
        else if (typeof frameValue === 'object' &&
            Array.isArray(frameValue)) {
            const payloadArray = payload[key];
            const frameValueArray = frameValue;
            if (!Array.isArray(payloadArray)) {
                throw new error_1.SdJwtError(`Frame expected array, but received ${typeof payload[key]} for key '${key}'.`);
            }
            if (frameValueArray.length > payloadArray.length) {
                throw new error_1.SdJwtError(`Frame array is longer than the payload array for ${key}`);
            }
            // Fill the frame with `false` if the payloadArray is longer than the frame value array
            if (payloadArray.length > frameValueArray.length) {
                payloadArray.forEach((_, index) => { var _a; return ((_a = frameValueArray[index]) !== null && _a !== void 0 ? _a : (frameValueArray[index] = false)); });
            }
            const newPayloadArray = [];
            for (let i = 0; i < payloadArray.length; i++) {
                const payloadValue = payloadArray[i];
                const frameValue = frameValueArray[i];
                if (frameValue) {
                    const salt = yield saltGenerator();
                    const disclosure = yield new disclosures_1.Disclosure(salt, payloadValue).withCalculateDigest(hasherAndAlgorithm);
                    disclosures.push(disclosure);
                    newPayloadArray.push({ '...': disclosure.digest });
                }
                else {
                    newPayloadArray.push(payloadValue);
                }
            }
            // @ts-ignore
            payload[key] = newPayloadArray;
        }
        else {
            throw new error_1.SdJwtError(`Invalid type in frame with key '${key}' and type '${typeof frameValue}'. Only Record<string, unknown>, arrays<boolean> and boolean are allowed.`);
        }
    }
    const payloadClone = Object.assign({}, payload);
    cleanup.forEach((path) => (0, utils_1.deleteByPath)(payloadClone, path));
    return { payload: payloadClone, disclosures };
});
exports.applyDisclosureFrame = applyDisclosureFrame;
//# sourceMappingURL=disclosureFrame.js.map